# pyslim

`pyslim` is a python module that provides a few extra tools for dealing with tree sequences
produced by SLiM and for preparing other tree seuqences for use with SLiM.
Most tree sequence functionality is provided by [tskit](https://tskit.dev/tskit).
Please see [our documentation](https://tskit.dev/pyslim/docs/stable/) for more information.
(That link is to documentation for the last release release;
instead, [the latest](https://tskit.dev/pyslim/docs/latest) documentation
may have additional examples, but may also describe features you need to install from github to get.)

## Installation

To install `pyslim`, do
```
pip install pyslim
```
or read the documentation for how to [install from source](https://tskit.dev/pyslim/stable/development.html#sec-development).
